@@ -1,5 +1,5 @@
 use super::EnumKind;
-use fxhash::FxHashMap;
+use rustc_hash::FxHashMap;
 use swc_atoms::js_word;
 use swc_common::{util::move_map::MoveMap, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
